Documentation
¶
Overview ¶
Package license helps manage commercial licenses and check if they are valid for the version of unidoc used.
Index ¶
Constants ¶
const ( LicenseTierUnlicensed = "unlicensed" LicenseTierCommunity = "community" LicenseTierIndividual = "individual" LicenseTierBusiness = "business" )
Variables ¶
This section is empty.
Functions ¶
func SetLicenseKey ¶
SetLicenseKey sets and validates the license key.
Types ¶
type LicenseKey ¶
type LicenseKey struct {
LicenseId string `json:"license_id"`
CustomerId string `json:"customer_id"`
CustomerName string `json:"customer_name"`
Tier string `json:"tier"`
CreatedAt time.Time `json:"-"`
CreatedAtInt int64 `json:"created_at"`
ExpiresAt *time.Time `json:"-"`
ExpiresAtInt int64 `json:"expires_at"`
CreatedBy string `json:"created_by"`
CreatorName string `json:"creator_name"`
CreatorEmail string `json:"creator_email"`
UniPDF bool `json:"unipdf"`
UniOffice bool `json:"unioffice"`
Trial bool `json:"trial"` // For trial licenses.
}
func MakeUnlicensedKey ¶
func MakeUnlicensedKey() *LicenseKey
func (*LicenseKey) ToString ¶
func (k *LicenseKey) ToString() string
func (*LicenseKey) TypeToString ¶
func (k *LicenseKey) TypeToString() string
func (*LicenseKey) Validate ¶
func (k *LicenseKey) Validate() error
Click to show internal directories.
Click to hide internal directories.